"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.StartCmd = void 0;
function _bitError() {
  const data = require("@teambit/bit-error");
  _bitError = function () {
    return data;
  };
  return data;
}
function _constants() {
  const data = require("@teambit/legacy/dist/constants");
  _constants = function () {
    return data;
  };
  return data;
}
function _openBrowser() {
  const data = _interopRequireDefault(require("react-dev-utils/openBrowser"));
  _openBrowser = function () {
    return data;
  };
  return data;
}
function _chalk() {
  const data = _interopRequireDefault(require("chalk"));
  _chalk = function () {
    return data;
  };
  return data;
}
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == typeof i ? i : String(i); }
function _toPrimitive(t, r) { if ("object" != typeof t || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != typeof i) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
class StartCmd {
  constructor(
  /**
   * access to the extension instance.
   */
  ui, logger) {
    this.ui = ui;
    this.logger = logger;
    _defineProperty(this, "name", 'start [component-pattern]');
    _defineProperty(this, "description", 'run the ui/development server');
    _defineProperty(this, "arguments", [{
      name: 'component-pattern',
      description: _constants().COMPONENT_PATTERN_HELP
    }]);
    _defineProperty(this, "alias", 'c');
    _defineProperty(this, "group", 'development');
    _defineProperty(this, "options", [['d', 'dev', 'start UI server in dev mode.'], ['p', 'port [port-number]', 'port of the UI server.'], ['r', 'rebuild', 'rebuild the UI (useful e.g. when updating the workspace UI - can use the dev flag for HMR in this case)'], ['', 'skip-ui-build', 'skip building UI'], ['v', 'verbose', 'show verbose output for inspection and prints stack trace'], ['n', 'no-browser', 'do not automatically open browser when ready'], ['', 'skip-compilation', 'skip the auto-compilation before starting the web-server'], ['u', 'ui-root-name [type]', 'name of the ui root to use, e.g. "teambit.scope/scope" or "teambit.workspace/workspace"']]);
  }
  async wait([userPattern], {
    dev,
    port,
    rebuild,
    verbose,
    noBrowser,
    skipCompilation,
    skipUiBuild,
    uiRootName: uiRootAspectIdOrName
  }) {
    const spinnies = this.logger.multiSpinner;
    if (!this.ui.isHostAvailable()) {
      throw new (_bitError().BitError)(`bit start can only be run inside a bit workspace or a bit scope - please ensure you are running the command in the correct directory`);
    }
    const appName = this.ui.getUiName(uiRootAspectIdOrName);
    await this.ui.invokePreStart({
      skipCompilation
    });
    this.logger.off();
    spinnies.add('ui-server', {
      text: `Starting UI server for ${appName}`
    });
    const uiServer = this.ui.createRuntime({
      uiRootAspectIdOrName,
      skipUiBuild,
      pattern: userPattern,
      dev,
      port: +port,
      rebuild,
      verbose
    });
    uiServer.then(async server => {
      const url = this.ui.publicUrl || server.fullUrl;
      spinnies.succeed('ui-server', {
        text: `UI server is ready at ${_chalk().default.cyan(url)}`
      });
      if (!server.buildOptions?.launchBrowserOnStart) return undefined;
      await server.whenReady;
      const name = server.getName();
      const message = _chalk().default.green(`You can now view '${_chalk().default.cyan(name)}' components in the browser.
Bit server is running on ${_chalk().default.cyan(url)}`);
      spinnies.add('summary', {
        text: message,
        status: 'non-spinnable'
      });
      if (!noBrowser) {
        (0, _openBrowser().default)(url);
      }
      return undefined;
    }).catch(error => this.logger.error(error));

    // DO NOT CHANGE THIS - this meant to be an async hook.
    // eslint-disable-next-line @typescript-eslint/no-floating-promises
    this.ui.invokeOnStart();
    this.ui.clearConsole();
  }
}
exports.StartCmd = StartCmd;

//# sourceMappingURL=start.cmd.js.map